@@ -1,12 +1,27 @@
 import collections
 import dataclasses
 import decimal
-import typing
+import sys
+from typing import Any, Union
+
+
+class GetAttr:
+    def __init__(self, args, kwargs):
+        self.args = args
+        self.kwargs = kwargs
 
 
 def cast(cls, x, implicit_conversions=None):
     if implicit_conversions and (cls in implicit_conversions):
         return implicit_conversions[cls](x)
+    elif isinstance(cls, GetAttr):
+        if "module" not in x:
+            raise TypeError(f'"module" key not in `x` for {cls}: {x}')
+        if "name" not in x:
+            raise TypeError(f'"name" key not in `x` for {cls}: {x}')
+        return getattr(sys.modules[x["module"]], x["name"])(
+            *cast(cls.args, x.get("args", [])), **cast(cls.kwargs, x.get("kwargs", {}))
+        )
     elif dataclasses.is_dataclass(cls):
         if not isinstance(x, dict):
             raise TypeError(f"{x}: {type(x)} is not compatible with {cls}")
@@ -28,7 +43,7 @@ def cast(cls, x, implicit_conversions=None):
                 for k, v in x.items()
             }
         )
-    elif cls == typing.Any:
+    elif cls == Any:
         return x
     elif cls == decimal.Decimal:
         if not isinstance(x, (str, int, float)):
@@ -50,19 +65,18 @@ def cast(cls, x, implicit_conversions=None):
         if x not in cls:
             raise TypeError(f"{x} is not compatible with {cls}")
         return x
-    elif cls.__origin__ == set or cls.__origin__ in (
-        collections.abc.Set,
-        collections.abc.MutableSet,
-    ):
+    elif cls.__origin__ in (set, collections.abc.Set, collections.abc.MutableSet,):
         vcls = cls.__args__[0]
         return set(cast(vcls, v, implicit_conversions=implicit_conversions) for v in x)
-    elif cls.__origin__ == list or cls.__origin__ in (
+    elif cls.__origin__ in (
+        list,
         collections.abc.Sequence,
         collections.abc.MutableSequence,
     ):
         vcls = cls.__args__[0]
         return [cast(vcls, v, implicit_conversions=implicit_conversions) for v in x]
-    elif cls.__origin__ == dict or cls.__origin__ in (
+    elif cls.__origin__ in (
+        dict,
         collections.abc.Mapping,
         collections.abc.MutableMapping,
     ):
@@ -73,9 +87,9 @@ def cast(cls, x, implicit_conversions=None):
             )
             for k, v in x.items()
         }
-    elif cls.__origin__ in (set, collections.deque):
+    elif cls.__origin__ == collections.deque:
         vcls = cls.__args__[0]
-        return cls.__origin__(
+        return collections.deque(
             cast(vcls, v, implicit_conversions=implicit_conversions) for v in x
         )
     elif cls.__origin__ == tuple:
@@ -86,7 +100,7 @@ def cast(cls, x, implicit_conversions=None):
             cast(vcls, v, implicit_conversions=implicit_conversions)
             for vcls, v in zip(vclss, x)
         )
-    elif cls.__origin__ == typing.Union:
+    elif cls.__origin__ == Union:
         for ucls in cls.__args__:
             try:
                 return cast(ucls, x, implicit_conversions=implicit_conversions)
